@@ -1,5 +1,5 @@
 /*
-   $Id: DB2.h,v 0.6 1996/10/07 18:00:05 mhm Rel $
+   $Id: DB2.h,v 0.8 1997/12/11 04:46:18 mhm Rel $
 
    Copyright (c) 1995  Mike Moran
 
@@ -11,12 +11,11 @@
 
 #define NEED_DBIXS_VERSION 7
 
-#include <DBIXS.h>		/* installed by the DBI module	*/
-
 #include <sqlcli.h>
 #include <sqlcli1.h>
 #include <sqlext.h>
 
+#include <DBIXS.h>		/* installed by the DBI module	*/
 
 /* read in our implementation details */
 
@@ -35,13 +34,13 @@ SV  *dbd_db_FETCH _((SV *dbh, SV *keysv));
 
 
 int  dbd_st_prepare _((SV *sth, char *statement, SV *attribs));
-int  dbd_st_rows _((SV *sv));
+int  dbd_st_rows    _((SV *sth, imp_sth_t *imp_sth));
 int  dbd_bind_ph _((SV *h, SV *param, SV *value, SV *attribs));
 int  dbd_st_execute _((SV *sv));
 AV  *dbd_st_fetch _((SV *sv));
-int  dbd_st_finish _((SV *sth));
-void dbd_st_destroy _((SV *sth));
-int  dbd_st_readblob _((SV *sth, int field, long offset, long len,
+int  dbd_st_finish _((SV *sth, imp_sth_t *imp_sth));
+int	 dbd_st_destroy _((SV *sth));
+int  dbd_st_blob_read _((SV *sth, int field, long offset, long len,
 			SV *destrv, long destoffset));
 int  dbd_st_STORE _((SV *dbh, SV *keysv, SV *valuesv));
 SV  *dbd_st_FETCH _((SV *dbh, SV *keysv));
